@@ -1,8 +1,9 @@
+import itertools
 import re
 from importlib import resources as ir
 from pathlib import Path
 from types import ModuleType
-from typing import Dict, Union
+from typing import Dict, List, Optional, Union
 
 from atc.configurator.configurator import Configurator
 from atc.configurator.sql import sqlparse
@@ -13,16 +14,34 @@ from atc.sql import BaseExecutor
 
 
 class SqlExecutor:
+    _DEFAULT = object()
+
     def __init__(
         self,
         base_module: Union[str, ModuleType] = None,
         server: BaseExecutor = None,
+        statement_spliter: Optional[List[str]] = _DEFAULT,
     ):
+        """Class to pre-treat sql statements and execute them.
+        Replacement sequenced related to the Configurator will be inserted before
+        execution.
+        Giving not statement_spliter is equivalent to [";", "-- COMMAND ----------"].
+        To disable splitting statements, please supply statement_spliter = None.
+        Semicolon will be treated correctly when quoted or in comments.
+
+        Default behavior supports spark, which will complain if given
+        no actual sql code or on multiple statements."""
+
         self.base_module = base_module
         self.server = server
+        if statement_spliter is self._DEFAULT:
+            # the sequence "-- COMMAND ----------" is used in jupyter notebooks
+            # and separates cells.
+            # We treat it as another way to end a statement
+            statement_spliter = [";", "-- COMMAND ----------"]
+        self.statement_spliter = statement_spliter
 
     def _wildcard_string_to_regexp(self, instr: str) -> str:
-
         # prepare file pattern:
         if instr.endswith(".sql"):
             instr = instr[:-4]
@@ -84,21 +103,42 @@ class SqlExecutor:
                     conts = file.read()
                     sql_code = conts.format(**replacements)
 
-                    # the sequence "-- COMMAND ----------" is used in jupyter notebooks
-                    # and separates cells.
-                    # We treat it as another way to end a statement
-                    sql_code = sql_code.replace("-- COMMAND ----------", ";")
-
-                    for statement in parse(sql_code):
-                        cleaned_statement = (
-                            "".join(
-                                token.value
-                                for token in statement
-                                if token.ttype not in sqlparse.tokens.Comment
+                    if self.statement_spliter is None:
+                        code_parts = [sql_code]
+                    elif ";" not in self.statement_spliter:
+                        code_parts = [sql_code]
+                        for sequence in self.statement_spliter:
+                            code_parts = itertools.chain.from_iterable(
+                                part.split(sequence) for part in code_parts
                             )
-                        ).strip()
 
-                        full_statement = "".join(token.value for token in statement)
+                    else:
+                        # if ; is included split the file into sql statements
+                        # by using parse, we ensure not to split by escaped or commented
+                        # occurrences of ;
+
+                        for marker in self.statement_spliter:
+                            if marker != ";":
+                                sql_code = sql_code.replace(marker, ";")
+
+                        code_parts = [
+                            "".join(token.value for token in statement)
+                            for statement in parse(sql_code)
+                        ]
+
+                    for full_statement in code_parts:
+                        cleaned_statement = (
+                            (
+                                "".join(
+                                    token.value
+                                    for statement in parse(full_statement)
+                                    for token in statement
+                                    if token.ttype not in sqlparse.tokens.Comment
+                                )
+                            )
+                            .strip()
+                            .strip(";")
+                        )
 
                         # skip the statement unless it actually contains code.
                         # spark.sql complains if you only give it comments
